@@ -40,3 +40,6 @@ def setup(app):
     StandardDomain.roles['magic'] = LineMagicRole()
     app.add_object_type('cellmagic', 'cellmagic', 'pair: %s; cell magic', parse_cell_magic)
     StandardDomain.roles['cellmagic'] = CellMagicRole()
+
+    metadata = {'parallel_read_safe': True, 'parallel_write_safe': True}
+    return metadata
